@@ -6,7 +6,7 @@ use Moo;
 use Encode ();
 
 # ABSTRACT: WebSocket message for AnyEvent
-our $VERSION = '0.41'; # VERSION
+our $VERSION = '0.43'; # VERSION
 
 
 has body => ( is => 'ro', required => 1 );
@@ -39,7 +39,7 @@ AnyEvent::WebSocket::Message - WebSocket message for AnyEvent
 
 =head1 VERSION
 
-version 0.41
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -144,11 +144,13 @@ Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
 Contributors:
 
-Toshio Ito
+Toshio Ito (debug-ito, TOSHIOITO)
 
-José Joaquín Atria
+José Joaquín Atria (JJATRIA)
 
-Kivanc Yazan
+Kivanc Yazan (KYZN)
+
+Yanick Champoux (YANICK)
 
 =head1 COPYRIGHT AND LICENSE
 
